# Embedding a Report in SharePoint
### On this page
  * [Step 1: Get the Report Code](https://help.sap.com/docs/leanix/ea/embedding-report-in-sharepoint#step-1:-get-the-report-code)
  * [Step 2: Embed the Report in SharePoint](https://help.sap.com/docs/leanix/ea/embedding-report-in-sharepoint#step-2:-embed-the-report-in-sharepoint)


Embed SAP LeanIX reports in SharePoint using the HTML iframe tag.
This guide explains how to embed a SAP LeanIX report in SharePoint using the HTML [iframe![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.w3schools.com%2Ftags%2Ftag_iframe.asp "https://www.w3schools.com/tags/tag_iframe.asp") tag.
